AlgoReason enum
Represents the different reasons returned from the AlgoSDK.
This enum defines various reasons that can be returned from the AlgoSDK during algorithm processing.
Values
- CONFIG_CHANGED → const AlgoReason
-
Configuration changed.
const AlgoReason(1) - USER_PROFILE_CHANGED → const AlgoReason
-
User profile changed.
const AlgoReason(2) - CB_CHANGED → const AlgoReason
-
CB changed.
const AlgoReason(3) - BY_USER → const AlgoReason
-
Changed by the user.
const AlgoReason(4) - BASELINE_EXPIRED → const AlgoReason
-
Baseline expired.
const AlgoReason(5) - NO_BASELINE → const AlgoReason
-
No baseline available.
const AlgoReason(6) - SIGNAL_QUALITY → const AlgoReason
-
Signal quality.
const AlgoReason(7) - MASK → const AlgoReason
-
Mask value for the enum.
const AlgoReason(255)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The integer value associated with the reason.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AlgoReason> - A constant List of the values in this enum, in order of their declaration.