HeadsetState enum
Represents the different states of the MindWave Mobile 2 headset.
This enum defines various states that the MindWave Mobile 2 headset can be in during initialization, connection, operation, and error conditions.
Values
- INIT → const HeadsetState
-
Initial state.
const HeadsetState(0) - CONNECTING → const HeadsetState
-
The headset is in the process of connecting.
const HeadsetState(1) - CONNECTED → const HeadsetState
-
The headset is successfully connected.
const HeadsetState(2) - WORKING → const HeadsetState
-
The headset is working, receiving data.
const HeadsetState(3) - STOPPED → const HeadsetState
-
The headset is stopped.
const HeadsetState(4) - DISCONNECTED → const HeadsetState
-
The headset is disconnected.
const HeadsetState(5) - COMPLETE → const HeadsetState
-
The connection process is complete.
const HeadsetState(6) - CONNECTION_FAILED → const HeadsetState
-
Connection failed.
const HeadsetState(100) - RECORDING_START → const HeadsetState
-
Recording started.
const HeadsetState(7) - RECORDING_END → const HeadsetState
-
Recording ended.
const HeadsetState(8) - ERROR → const HeadsetState
-
Error occurred.
const HeadsetState(101) - GET_DATA_TIME_OUT → const HeadsetState
-
Timeout occurred while waiting for data.
const HeadsetState(9) - CHECK_SUM_FAIL → const HeadsetState
-
Checksum failed.
const HeadsetState(1000) - RECORD_FAIL → const HeadsetState
-
Recording failed.
const HeadsetState(1001)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The integer value associated with the state.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
HeadsetState> - A constant List of the values in this enum, in order of their declaration.